
.. autosummary::
    :toctree: _source/
    
################################
Related publications
################################

This page lists research papers and reports that use PowNet 2.0 (or its predecessor). Please let us know if you would like to add your work to this list.



**Research papers**

- **Bunnak, P., Coniglio, S., & Galelli, S. (2025)**. Bridging theory and practice: Efficiently solving the unit commitment problem in production cost models. Energy, 322, 135454.


*Predecessor to PowNet 2.0*

- **Arnold, W., Giuliani, M., & Castelletti, A. (2024)**. Floating photovoltaics may reduce the risk of hydro-dominated energy development in Africa. Nature Energy, 9(5), 602-611.

- **Koh, R., & Galelli, S. (2024)**. Evaluating streamflow forecasts in hydro‐dominated power systems—When and why they matter. Water Resources Research, 60(3), e2023WR035825.

- **Koh, R., & Galelli, S. (2023)**. Evaluating Streamflow Forecasts in Hydro-Dominated Power Systems--When and Why They Matter. Authorea Preprints.

- **Koh, R., Kern, J., & Galelli, S. (2022)**. Hard-coupling water and power system models increases the complementarity of renewable energy sources. Applied Energy, 321, 119386.

- **Galelli, S., Dang, T. D., Ng, J. Y., Chowdhury, A. K., & Arias, M. E. (2022)**. Opportunities to curb hydrological alterations via dam re-operation in the Mekong. Nature Sustainability, 5(12), 1058-1069.

- **Chowdhury, A. K., Dang, T. D., Nguyen, H. T., Koh, R., & Galelli, S. (2021)**. The Greater Mekong's climate‐water‐energy nexus: How ENSO‐triggered regional droughts affect power supply and CO2 emissions. Earth's Future, 9(3), e2020EF001814.


- **Chowdhury, A. K., Dang, T. D., Bagchi, A., & Galelli, S. (2020)**. Expected benefits of Laos’ hydropower development curbed by hydroclimatic variability and limited transmission capacity: Opportunities to reform. Journal of Water Resources Planning and Management, 146(10), 05020019.

- **Chowdhury, A. K., Kern, J., Dang, T. D., & Galelli, S. (2020)**. PowNet: a network-constrained unit commitment/economic dispatch model for large-scale power systems analysis. Journal of Open Research Software, 8(1).



**Conference presentations**

- **Galelli, S., Eldardiry, H., & Bunnak, P. (2025).** Towards real-time operation of interconnected water-energy systems (No. EGU25-7249). Copernicus Meetings.

- **Galelli, S., Bunnak, P., Eldardiry, H., & Koh, R. (2025).** Evaluating Streamflow Forecasts in Hydro-Dominated Power Systems (No. EGU25-7232). Copernicus Meetings.

- **Eldardiry, H., Bunnak, P., Thomsen, G., & Galelli, S. (2024)**. Orchestrating Hydropower Dispatch Decisions over Wide-Area Synchronous Grids. AGU24.

- **Giuliani, M., Castelletti, A., Carlino, A., & Arnold, W. (2024, April)**. Reconsidering hydropower in the African energy transition. In EGU General Assembly Conference Abstracts (p. 7354).

- **Leoni, A., Stevanato, N., Carlino, A., Castelletti, A. F., & Giuliani, M. (2024, April)**. From multi-decadal energy planning to hourly power dispatch: evaluating the reliability of energy projections in the Southern African Power Pool. In EGU General Assembly Conference Abstracts (p. 6025).

- **Bunnak, P., Dang, T. D., & Galelli, S. (2022, December)**. Evaluating the Effect of Climate Change on the Power Systems of Mainland Southeast Asia. In AGU Fall Meeting Abstracts (Vol. 2022, pp. GC14E-01).

- **Feng, Z., Bunnak, P., & Galelli, S. (2022, December)**. Characterizing Malaysia's Transition into a Liberalized Electricity Market. In AGU Fall Meeting Abstracts (Vol. 2022, pp. GC51E-02).



